@@ -11,8 +11,12 @@ avec Aiguillier pour disposer d'une base locale afin de faire
 des calculs sans craindre les ralentissements réseau. Toutes
 les vérifications se font donc en local.
 """
+import smtplib
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from email.utils import formatdate
 
-from .consts import FUPDB_CREDENTIALS
+from .consts import FUPDB_CREDENTIALS, APIGW, LOGS
 
 import records
 import psycopg2
@@ -93,4 +97,34 @@ def update_customer_cdr(last_date, customer):
         last_date=last_date
         )
 
+
+def send_error_report(operation, error):
+    """
+    Sends an email to development and monitoring team to notify an error
+    in the process.
+    """
+    message = (
+        "Service: {} [{}]\n\n"
+        "Affected operation: {}\n\n"
+        "Error: {}"
+        .format("fup-services", APIGW, operation, error)
+    )
+    sender = "api-gateway@si.blueline.mg"
+    destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
+    content = MIMEText(message, 'plain', 'utf-8')
+
+    msg = MIMEMultipart()
+    msg['Subject'] = "fup-services process error"
+    msg['From'] = sender
+    msg['To'] = ', '.join(destinations)
+    msg['Date'] = formatdate(localtime=True)
+    msg.attach(content)
+    smtp = smtplib.SMTP('localhost')
+    smtp.sendmail(sender, destinations, msg.as_string())
+    smtp.quit()
+
+    LOGS.logger.info(
+        "Email: '{}' sent to {}".format(msg['Subject'], destinations))
+    smtp.quit()
+
 # EOF
