@@ -241,28 +241,38 @@ class Customer(object):
             msg
             ):
         api_request = getattr(REST_CLIENT, method)
-        response = api_request(
-            '/fup',
-            auth=(
-                CONFIG['AIGUILLIER']['username'],
-                CONFIG['AIGUILLIER']['password']
-                ),
-            params=params
+        try:
+            response = api_request(
+                '/fup',
+                auth=(
+                    CONFIG['AIGUILLIER']['username'],
+                    CONFIG['AIGUILLIER']['password']
+                    ),
+                params=params
+                )
+            LOGS.logger.info(
+                "[FUP/DEFUP] Customer {} {operation} from Aiguiller: "
+                "api request: {}, "
+                "parameters: {}, "
+                "response: {} {}"
+                .format(
+                    self.name,
+                    api_request,
+                    params,
+                    response,
+                    response.text,
+                    operation=msg,
+                )
             )
-        LOGS.logger.info(
-            "[FUP/DEFUP] Customer {} {operation} from Aiguiller: "
-            "api request: {}, "
-            "parameters: {}, "
-            "response: {} {}"
-            .format(
-                self.name,
-                api_request,
-                params,
-                response,
-                response.text,
-                operation=msg,
+        except Exception as e:
+            LOGS.logger.error(
+                "Unable to {} customer {} from Aiguillier: {}"
+                .format(msg, self.name, str(e))
+            )
+            core.send_error_report(
+                "{} Customer from Aiguillier".format(msg),
+                str(e)
             )
-        )
         LOGS.logger.info("{} un client {}-{}-{}-{}".format(
             msg,
             self.name,
@@ -429,6 +439,50 @@ class Customer(object):
     def get_cdr_from_aiguillier(self, last_date):
         """Récupération des CDRs a une date donné
         depuis l'API d'Aiguillier pour les clients"""
+
+        # ====================================================================
+        #  TODO: fetch CDRs directly from BI database
+        # url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+        #     eng=CONFIG['BI']['engine'],
+        #     user=CONFIG['BI']['user'],
+        #     password=CONFIG['BI']['password'],
+        #     host=CONFIG['BI']['host'],
+        #     port=CONFIG['BI']['port'],
+        #     name=CONFIG['BI']['table_name']
+        # )
+        # sql = (
+        #     "SELECT * FROM all_cdr WHERE "
+        #     "clientname='{}' AND "
+        #     "sessiontime >= '{}'::date"
+        #     .format(self.name, last_date)
+        # )
+        # try:
+        #     with records.Database(url) as db:
+        #         rows = db.query(sql)
+        #         cdrs_raw = rows.as_dict()
+        #     LOGS.logger.info(
+        #         "{} CRDs fetched from BI database for customer {}"
+        #         .format(len(cdrs_raw), self.name)
+        #     )
+        # except Exception as e:
+        #     LOGS.logger.error(
+        #         "Unable to fetch customer {} CDRs: {}"
+        #         .format(self.name, str(e))
+        #     )
+        #     core.send_error_report("CDRs synchronization", str(e))
+        #     # we don't raise an exception, we assume customer has not used
+        #     # their Internet
+        #
+        # cdrs = sorted(
+        #     cdrs_raw or [],
+        #     key=lambda x: datetime.strptime(
+        #         x['sessiontime'],
+        #         '%Y-%m-%dT%H:%M:%S'
+        #     )
+        # )
+        # ====================================================================
+
+        # =================== fetching CRDs via Aiguiller ====================
         import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
@@ -437,65 +491,43 @@ class Customer(object):
         for i in range(3):
             if OK:
                 break
-            msg = (
-                "Try {}/3: Fetching customer {} CDR from {} from Aiguiller: "
-                .format(i, self.name, last_date)
-            )
             try:
-                response = REST_CLIENT.get(
-                    '/fup',
+                response = requests.get(
+                    CONFIG['AIGUILLIER']['url_v2'] + "/consommation",
                     auth=(
                         CONFIG['AIGUILLIER']['username'],
                         CONFIG['AIGUILLIER']['password']
-                        ),
-                    params={'customer': self.name, 'fromdate': last_date}
-                    )
-                LOGS.logger.info(msg + str(response))
+                    ),
+                    params={"client": self.name, "depuis_date": last_date}
+                )
+                LOGS.logger.info("essai {} de {}".format(i, self.name))
                 infos = response['content']
+                LOGS.logger.warn('Value {}'.format(infos))
                 if infos['status']:
                     OK = True
-            except Exception as e:
-                LOGS.logger.error(msg + str(e))
+            except requests.exceptions.Timeout:
+                LOGS.logger.info("essai TimeoutError {} de {}".format(
+                    i,
+                    self.name
+                ))
                 time.sleep(60)
                 continue
-        # nill_condition = (
-        #    'refnum' not in infos or
-        #    infos['product'] not in [i.name for i in product.Product.all()]
-        #    )
-        # if nill_condition:
-        # le client n'existe plus
-        # ou son produit a changé et il n'est plus concerné
-        # par le fup
-        #    customer_status = self.fup_status
-        #    for policy_name in self.product.policies:
-        #        status = customer_status.get(policy_name)
-        #        if status:
-        #            status = sorted(
-        #                status,
-        #                key=lambda x: x['datetime'],
-        #                reverse=True
-        #                )
-        #            if status[0]['status']:
-        #                # si le client était fup, il faut le défup
-        #                REST_CLIENT.delete(
-        #                    '/fup',
-        #                    auth=(
-        #                        CONFIG['AIGUILLIER']['username'],
-        #                        CONFIG['AIGUILLIER']['password']
-        #                        ),
-        #                    params={'customer': self.name}
-        #                    )
-        #    url = core.database_url(**FUPDB_CREDENTIALS)
-        #    with records.Database(url) as db:
-        #        sql = "DELETE FROM customer WHERE name=:name"
-        #        db.query(sql, name=self.name)
-        #        sql = "DELETE FROM cdr WHERE customer=:name"
-        #        db.query(sql, name=self.name)
-        #        sql = "DELETE FROM fup WHERE customer=:name"
-        #        db.query(sql, name=self.name)
-        #    LOGS.logger.info("Suppression du client {}".format(self.name))
-        #    return None
-        # else:
+            except ValueError:
+                LOGS.logger.info("essai ValueError {} de {}".format(
+                    i,
+                    self.name
+                ))
+                time.sleep(60)
+                continue
+            except Exception as e:
+                LOGS.logger.error(
+                    "Unable to fetch customer {} CDRs: {}"
+                    .format(self.name, str(e))
+                )
+                core.send_error_report("CDRs synchronization", str(e))
+                # we don't raise an exception, we assume customer has not used
+                # their Internet
+
         if type(infos) is str:
             infos = json.loads(infos)
         cdrs = sorted(
@@ -503,8 +535,8 @@ class Customer(object):
             key=lambda x: datetime.strptime(
                 x['sessiontime'],
                 '%Y-%m-%dT%H:%M:%S'
-                )
             )
+        )
         cdrs = groupby(
             cdrs,
             key=lambda x: datetime.strptime(
